import tenacity
from typing import Union

from csp_cbc_auth.cbc.session import CBCSession
from psc_auth_integration.entities.auth_user_session import AuthUserSession

from cbc_content_reporting.api_clients.base_api_class import ReportingBaseClass


class ReportingHealthApi(ReportingBaseClass):

    def __init__(self, session: Union[AuthUserSession, CBCSession]):
        super().__init__(session)
        self.health_check_url = f'{self.reporting_base_url}/v1/health_check'

    @tenacity.retry(wait=tenacity.wait_fixed(5), stop=tenacity.stop_after_attempt(12), reraise=True)
    def get_health_check(self):
        """
        /health_check call to ensure service is healthy and ready
        :return: dict json response
        """
        response = self.get(url=self.health_check_url)
        return response.json()
